==================================
python-anyconfig-json5-backend
==================================

.. image:: https://img.shields.io/pypi/v/anyconfig-json5-backend.svg
   :target: https://pypi.python.org/pypi/anyconfig-json5-backend/
   :alt: [Latest Version]

.. image:: https://img.shields.io/pypi/pyversions/anyconfig-json5-backend.svg
   :target: https://pypi.python.org/pypi/anyconfig-json5-backend/
   :alt: [Python versions]

.. image:: https://img.shields.io/pypi/l/anyconfig-json5-backend.svg
   :target: https://pypi.python.org/pypi/anyconfig-json5-backend/
   :alt: MIT License

.. image:: https://github.com/ssato/python-anyconfig-json5-backend/workflows/Tests/badge.svg
   :target: https://github.com/ssato/python-anyconfig-json5-backend/actions?query=workflow%3ATests
   :alt: GitHub Actions Test status

.. image:: https://dev.azure.com/satorusatoh0471/python-anyconfig-json5-backend/_apis/build/status/ssato.python-anyconfig-json5-backend?branchName=master
   :target: https://dev.azure.com/satorusatoh0471/python-anyconfig-json5-backend/_build/latest?definitionId=1
   :alt: [Azure Pipelines Status]

.. .. image:: https://img.shields.io/coveralls/ssato/python-anyconfig-json5-backend.svg
   :target: https://coveralls.io/r/ssato/python-anyconfig-json5-backend
   :alt: Coverage Status

.. image:: https://img.shields.io/lgtm/alerts/g/ssato/python-anyconfig-json5-backend.svg
   :target: https://lgtm.com/projects/g/ssato/python-anyconfig-json5-backend/alerts/
   :alt: [Total Alerts by LGTM]

.. image:: https://img.shields.io/lgtm/grade/python/g/ssato/python-anyconfig-json5-backend.svg
   :target: https://lgtm.com/projects/g/ssato/python-anyconfig-json5-backend/context:python
   :alt: [Code Quality by LGTM]

This is a backend module for python-anyconfig to support to load and dump
json5' data files.

- Author: Satoru SATOH <satoru.satoh@gmail.com>
- License: MIT

SEE ALSO:

- python-anyconfig: https://pypi.python.org/pypi/anyconfig
- JSON5: https://json5.org

Build packages
================

Try::

  $ tox -e dists
  
.. vim:sw=2:ts=2:et:
